@@ -7,7 +7,7 @@ import torch
 from einops import rearrange, repeat
 from pytorch_lightning import seed_everything
 
-import config
+import classy_imaginary.config as config
 from classy_imaginary.api import _prompts_to_embeddings, IMAGINAIRY_SAFETY_MODE
 from classy_imaginary import ImaginePrompt, ImagineResult
 from classy_imaginary.enhancers.clip_masking import get_img_mask
